Skip site navigation (1)Skip section navigation (2)
Date:      Sun, 22 Jul 2001 12:11:12 +0200
From:      Tor.Egge@fast.no
To:        david@catwhisker.org
Cc:        current@FreeBSD.ORG
Subject:   Re: Interruptable hang starting init in today's -CURRENT
Message-ID:  <200107221011.MAA01533@midten.fast.no>
In-Reply-To: Your message of "Thu, 5 Jul 2001 12:04:18 -0700 (PDT)"
References:  <200107051904.f65J4I217302@bunrab.catwhisker.org>

next in thread | previous in thread | raw e-mail | index | archive | help
----Next_Part(Sun_Jul_22_12:07:57_2001)--
Content-Type: Text/Plain; charset=us-ascii
Content-Transfer-Encoding: 7bit


> Interestingly, "sysctl -a -N" spits out names, but then seems to fall
> into a rut:
> 
[....]
> net.inet.udp.getcred
> net.inet.accf.unloadable
> net.inet.accf.373
> net.inet.accf.373
> net.inet.accf.373
[....]

> Looks as if it's looping with no termination conditions being matched.

When I got the same problem on my -current machine today, I found that
net.inet.accf and net.inet.raw had the same oid.

The system booted normally after changing the start oid for
dynamically assigned sysctl entries from 100 to 256.

- Tor Egge


----Next_Part(Sun_Jul_22_12:07:57_2001)--
Content-Type: Text/Plain; charset=us-ascii
Content-Transfer-Encoding: 7bit

Index: sys/kern/kern_sysctl.c
===================================================================
RCS file: /home/ncvs/src/sys/kern/kern_sysctl.c,v
retrieving revision 1.110
diff -u -r1.110 kern_sysctl.c
--- sys/kern/kern_sysctl.c	2001/06/22 19:54:38	1.110
+++ sys/kern/kern_sysctl.c	2001/07/22 09:33:11
@@ -110,10 +110,10 @@
 	/*
 	 * If this oid has a number OID_AUTO, give it a number which
 	 * is greater than any current oid.  Make sure it is at least
 	 * 100 to leave space for pre-assigned oid numbers.
 	 */
 	if (oidp->oid_number == OID_AUTO) {
-		static int newoid = 100;
+		static int newoid = 256;
 
 		oidp->oid_number = newoid++;
 		if (newoid == 0x7fffffff)

----Next_Part(Sun_Jul_22_12:07:57_2001)----
@@ -110,10 +110,10 @@
 	 * If this oid has a number OID_AUTO, give it a number which
 	 * is greater than any current oid.  Make sure it is at least
-	 * 100 to leave space for pre-assigned oid numbers.
+	 * 256 to leave space for pre-assigned oid numbers.
 	 */
 	if (oidp->oid_number == OID_AUTO) {

To Unsubscribe: send mail to majordomo@FreeBSD.org
with "unsubscribe freebsd-current" in the body of the message




Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?200107221011.MAA01533>